@@ -52,7 +52,7 @@ func (n *Node) ToggleCordon(path string, cordon bool) error {
 		}
 		return fmt.Errorf("node is already uncordoned")
 	}
-	dial, err := n.Factory.Client().Dial()
+	dial, err := n.GetFactory().Client().Dial()
 	if err != nil {
 		return err
 	}
@@ -84,7 +84,7 @@ func (o DrainOptions) toDrainHelper(k kubernetes.Interface, w io.Writer) drain.H
 func (n *Node) Drain(path string, opts DrainOptions, w io.Writer) error {
 	_ = n.ToggleCordon(path, true)
 
-	dial, err := n.Factory.Client().Dial()
+	dial, err := n.GetFactory().Client().Dial()
 	if err != nil {
 		return err
 	}
@@ -170,7 +170,7 @@ func (n *Node) List(ctx context.Context, ns string) ([]runtime.Object, error) {
 // CountPods counts the pods scheduled on a given node.
 func (n *Node) CountPods(nodeName string) (int, error) {
 	var count int
-	oo, err := n.Factory.List("v1/pods", client.AllNamespaces, false, labels.Everything())
+	oo, err := n.GetFactory().List("v1/pods", client.AllNamespaces, false, labels.Everything())
 	if err != nil {
 		return 0, err
 	}
@@ -194,7 +194,7 @@ func (n *Node) CountPods(nodeName string) (int, error) {
 
 // GetPods returns all pods running on given node.
 func (n *Node) GetPods(nodeName string) ([]*v1.Pod, error) {
-	oo, err := n.Factory.List("v1/pods", client.AllNamespaces, false, labels.Everything())
+	oo, err := n.GetFactory().List("v1/pods", client.AllNamespaces, false, labels.Everything())
 	if err != nil {
 		return nil, err
 	}
