@@ -5,6 +5,7 @@ import (
 
 	"github.com/derailed/k9s/internal/client"
 	"github.com/gdamore/tcell/v2"
+	"github.com/rs/zerolog/log"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 )
@@ -100,6 +101,35 @@ func NewPolicyRes(ns, binding, res, grp string, vv []string) PolicyRes {
 	}
 }
 
+// GR returns the group/resource path.
+func (p PolicyRes) GR() string {
+	return p.Group + "/" + p.Resource
+}
+
+func (p PolicyRes) Merge(p1 PolicyRes) (PolicyRes, error) {
+	if p.GR() != p1.GR() {
+		return PolicyRes{}, fmt.Errorf("policy mismatch %s vs %s", p.GR(), p1.GR())
+	}
+
+	for _, v := range p1.Verbs {
+		if !p.hasVerb(v) {
+			p.Verbs = append(p.Verbs, v)
+		}
+	}
+
+	return p, nil
+}
+
+func (p PolicyRes) hasVerb(v1 string) bool {
+	for _, v := range p.Verbs {
+		if v == v1 {
+			return true
+		}
+	}
+
+	return false
+}
+
 // GetObjectKind returns a schema object.
 func (p PolicyRes) GetObjectKind() schema.ObjectKind {
 	return nil
@@ -115,19 +145,24 @@ type Policies []PolicyRes
 
 // Upsert adds a new policy.
 func (pp Policies) Upsert(p PolicyRes) Policies {
-	idx, ok := pp.find(p.Resource)
+	idx, ok := pp.find(p.GR())
 	if !ok {
 		return append(pp, p)
 	}
+	p, err := pp[idx].Merge(p)
+	if err != nil {
+		log.Error().Err(err).Msg("policy upsert failed")
+		return pp
+	}
 	pp[idx] = p
 
 	return pp
 }
 
 // Find locates a row by id. Returns false is not found.
-func (pp Policies) find(res string) (int, bool) {
+func (pp Policies) find(gr string) (int, bool) {
 	for i, p := range pp {
-		if p.Resource == res {
+		if p.GR() == gr {
 			return i, true
 		}
 	}
