@@ -13,10 +13,34 @@ import (
 	"github.com/derailed/k9s/internal/model"
 	"github.com/derailed/k9s/internal/render"
 	"github.com/derailed/k9s/internal/ui"
+	"github.com/derailed/tview"
 	"github.com/gdamore/tcell/v2"
 	"github.com/rs/zerolog/log"
+	"golang.design/x/clipboard"
 )
 
+func clipboardWrite(text string) error {
+	if err := clipboard.Init(); err != nil {
+		return err
+	}
+	if clipboard.Write(clipboard.FmtText, []byte(text)) == nil {
+		return errors.New("unable to write to clipboard")
+	}
+	return nil
+}
+
+func cpCmd(flash *model.Flash, v *tview.TextView) func(*tcell.EventKey) *tcell.EventKey {
+	return func(evt *tcell.EventKey) *tcell.EventKey {
+		if err := clipboardWrite(v.GetText(true)); err != nil {
+			flash.Err(err)
+			return evt
+		}
+		flash.Info("Content copied to clipboard...")
+
+		return nil
+	}
+}
+
 func parsePFAnn(s string) (string, string, bool) {
 	tokens := strings.Split(s, ":")
 	if len(tokens) != 2 {
