@@ -3,7 +3,6 @@ package view
 import (
 	"context"
 
-	"github.com/atotto/clipboard"
 	"github.com/derailed/k9s/internal/config"
 	"github.com/derailed/k9s/internal/model"
 	"github.com/derailed/k9s/internal/ui"
@@ -70,7 +69,7 @@ func (l *Logger) bindKeys() {
 	l.actions.Set(ui.KeyActions{
 		tcell.KeyEscape: ui.NewKeyAction("Back", l.resetCmd, false),
 		tcell.KeyCtrlS:  ui.NewKeyAction("Save", l.saveCmd, false),
-		ui.KeyC:         ui.NewKeyAction("Copy", l.cpCmd, true),
+		ui.KeyC:         ui.NewKeyAction("Copy", cpCmd(l.app.Flash(), l.TextView), true),
 		ui.KeySlash:     ui.NewSharedKeyAction("Filter Mode", l.activateCmd, false),
 		tcell.KeyDelete: ui.NewSharedKeyAction("Erase", l.eraseCmd, false),
 	})
@@ -160,12 +159,3 @@ func (l *Logger) saveCmd(evt *tcell.EventKey) *tcell.EventKey {
 
 	return nil
 }
-
-func (l *Logger) cpCmd(evt *tcell.EventKey) *tcell.EventKey {
-	l.app.Flash().Info("Content copied to clipboard...")
-	if err := clipboard.WriteAll(l.GetText(true)); err != nil {
-		l.app.Flash().Err(err)
-	}
-
-	return nil
-}
